GlyphPainter

Struct GlyphPainter 

pub(crate) struct GlyphPainter<'a> {
    pub(crate) font: &'a FontRef<'a>,
    pub(crate) location: LocationRef<'a>,
    pub(crate) svg: &'a mut XmlWriter,
    pub(crate) path_buf: &'a mut String,
    pub(crate) gradient_index: usize,
    pub(crate) clip_path_index: usize,
    pub(crate) foreground_color: Color,
    pub(crate) transform: Transform,
    pub(crate) outline_transform: Transform,
    pub(crate) transforms_stack: Vec<Transform>,
    pub(crate) clip_stack: Vec<Option<Rect>>,
}

Fields

font: &'a FontRef<'a>location: LocationRef<'a>

The variation location to draw outlines at.

svg: &'a mut XmlWriterpath_buf: &'a mut Stringgradient_index: usizeclip_path_index: usizeforeground_color: Colortransform: Transformoutline_transform: Transformtransforms_stack: Vec<Transform>clip_stack: Vec<Option<Rect>>

The bounding box of every active clip, in the root coordinate space. None means the clip is empty (or its bounds are unknown).

Implementations

Source

impl<'a> GlyphPainter<'a>

fn write_gradient_stops(&mut self, stops: &[ColorStop])

fn paint_solid(&mut self, color: Color)

fn paint_linear_gradient( &mut self, p0: Point<f32>, p1: Point<f32>, color_stops: &[ColorStop], extend: Extend, )

fn paint_radial_gradient( &mut self, c0: Point<f32>, r0: f32, c1: Point<f32>, r1: f32, color_stops: &[ColorStop], extend: Extend, )

fn paint_sweep_gradient( &mut self, _c0: Point<f32>, _start_angle: f32, _end_angle: f32, _color_stops: &[ColorStop], _extend: Extend, )

Source

impl GlyphPainter<'_>

fn clip_with_path(&mut self, path: &str)

fn outline_glyph(&mut self, glyph_id: GlyphId) -> Option<Rect>

Outlines a glyph into path_buf at the current variation location (an empty path on failure), records the current transform as the outline transform and returns the outline’s conservative bounding box in the glyph’s local coordinate space.

fn paint_brush(&mut self, brush: Brush<'_>)

Paints path_buf (positioned by the outline transform) with the given brush.

fn palette_index_to_color(&self, palette_index: u16, alpha: f32) -> Color