struct Builder<'a> {
path: &'a mut String,
min_x: f32,
min_y: f32,
max_x: f32,
max_y: f32,
}Fields
path: &'a mut Stringmin_x: f32min_y: f32max_x: f32max_y: f32Implementations
Sourceimpl<'a> Builder<'a>
impl<'a> Builder<'a>
fn new(path: &'a mut String) -> Self
fn add_point(&mut self, x: f32, y: f32)
Sourcefn bounds(&self) -> Option<Rect>
fn bounds(&self) -> Option<Rect>
Returns a conservative bounding box of the written path. It includes curve control points, so it can be larger than the exact bounding box, but never smaller.
fn finish(&mut self)